package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jun 8, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func IsTrivyPluginMode() bool
IsTrivyPluginMode returns whether the binary is being executed as a trivy plugin mode.
Not robust.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.